Stan Math Library: stan/math/prim/scal/fun/inc_beta_ddb.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
inc_beta_ddb.hpp File Reference
`#include <stan/math/prim/scal/fun/inc_beta.hpp>`
`#include <stan/math/prim/scal/fun/inc_beta_dda.hpp>`
`#include <cmath>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T | stan::math::inc_beta_dda (T a, T b, T z, T digamma_a, T digamma_ab)
| Returns the partial derivative of the regularized incomplete beta function, I_{z}(a, b) with respect to a. More...
template<typename T >
T | stan::math::inc_beta_ddb (T a, T b, T z, T digamma_b, T digamma_ab)
| Returns the partial derivative of the regularized incomplete beta function, I_{z}(a, b) with respect to b. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.